Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/edwh_auth_rbac/__init__.py | 3 | 0 | 0 | 100%
src/edwh_auth_rbac/helpers.py | 6 | 1 | 0 | 83%
src/edwh_auth_rbac/migrations.py | 9 | 0 | 0 | 100%
src/edwh_auth_rbac/model.py | 183 | 44 | 0 | 76%
src/edwh_auth_rbac/rbac.py | 88 | 39 | 0 | 56%
tests/__init__.py | 0 | 0 | 0 | 100%
tests/test_rbac.py | 106 | 2 | 0 | 98%
Total | 395 | 86 | 0 | 78%

No items found using the specified filter.